import React from 'react'
import './MyComponent.css'

export default function MyComponent() {
  return (
    <div className='MyComponent'>
      <h1 className='MyComponent-title'>
        Hello Django React
      </h1>
    </div>
  )
}